-- Load configuration options up front
ScriptHost:LoadScript("scripts/settings.lua")
ScriptHost:LoadScript("scripts/common.lua")

-- Are we using a keysanity variant?
IS_KEYSANITY = string.find(Tracker.ActiveVariantUID, "keys") ~= nil

-- Blitz mode?
IS_BLITZ = string.find(Tracker.ActiveVariantUID, "blitz") ~= nil

-- Items
Tracker:AddItems("items/common.json")
if IS_KEYSANITY then
    Tracker:AddItems("items/dungeon_items_keysanity.json")
else
    Tracker:AddItems("items/dungeon_items_standard.json")
end
Tracker:AddItems("items/keys.json")
Tracker:AddItems("items/labels.json")

-- Maps
if IS_KEYSANITY then
    Tracker:AddMaps("maps/maps_keysanity.json")
else
    Tracker:AddMaps("maps/maps.json")
end

-- Locations (load SM cards first for portal logic)
if IS_KEYSANITY then
    Tracker:AddLocations("locations/sm/cards_keysanity.json")
else
    Tracker:AddLocations("locations/sm/cards_standard.json")
end
Tracker:AddLocations("locations/logic.json")
Tracker:AddLocations("locations/alttp/lightworld.json")
Tracker:AddLocations("locations/alttp/darkworld.json")
Tracker:AddLocations("locations/alttp/bothworlds.json")
if IS_KEYSANITY then
    Tracker:AddLocations("locations/alttp/dungeons_keysanity.json")
    Tracker:AddLocations("locations/sm/doors_keysanity.json")
else
    Tracker:AddLocations("locations/alttp/dungeons_standard.json")
    Tracker:AddLocations("locations/sm/doors_standard.json")
end
Tracker:AddLocations("locations/sm/wreckedship.json")
Tracker:AddLocations("locations/sm/crateria.json")
Tracker:AddLocations("locations/sm/brinstar.json")
Tracker:AddLocations("locations/sm/norfairupper.json")
Tracker:AddLocations("locations/sm/norfairlower.json")
Tracker:AddLocations("locations/sm/maridia.json")

-- Layouts
Tracker:AddLayouts("layouts/common.json")
if IS_KEYSANITY then
    Tracker:AddLayouts("layouts/tracker_keysanity.json")
    Tracker:AddLayouts("layouts/broadcast_keysanity.json")
elseif IS_BLITZ then
    Tracker:AddLayouts("layouts/tracker_blitz.json")
    Tracker:AddLayouts("layouts/broadcast_blitz.json")
    -- Set fast Ganon, and 0/0/0 required bosses for Blitz logic.
    ganon_entry = Tracker:FindObjectForCode("ganon_entry")
    ganon_entry.CurrentStage = 2
    for _, ref in ipairs({"mb", "gt_crystals", "ganon_crystals"}) do
        item = Tracker:FindObjectForCode(ref)
        item.AcquiredCount = 0
    end
else
    Tracker:AddLayouts("layouts/tracker_standard.json")
    Tracker:AddLayouts("layouts/broadcast_standard.json")
end

-- Autotracking if supported
if _VERSION == "Lua 5.3" then
    ScriptHost:LoadScript("scripts/autotracking.lua")
else
    print("Autotracking is unsupported by your EmoTracker version, please update to the latest version!")
end
